# ElasticTools - high-speed utilities for ElasticSearch data manipulations

`ElasticTools` is a python package developed as a handy utility for cases when it comes to **streaming**, **manipulation** or **processing** of any sort of data stored (or prone to be stored) within ElasticSearch.

The key features are:

- **Highly performant**. Written purely in python with a dense usage of concurrency thanks to AsyncIO.

- **Intuitive**. Though almost every commandline argument has a detailed explanation of *what* is it and *why* we need it, one can intuitively answer those questions.

- **Consize**. Thanks to usage of abstract classes and OOP implementations a lot of duplications are reduced.
